@@ -41,6 +41,9 @@ FAILEDOPERATION_CONFINUSED = 'FailedOperation.ConfInUsed'
 # The domain name cannot be deleted because it incurred traffic in the last 2 days and is in locked state.
 FAILEDOPERATION_DELETEDOMAININLOCKEDTIME = 'FailedOperation.DeleteDomainInLockedTime'
 
+# 
+FAILEDOPERATION_DOMAINGSLBFAIL = 'FailedOperation.DomainGslbFail'
+
 # Unable to get the watermark URL.
 FAILEDOPERATION_GETPICTUREURLERROR = 'FailedOperation.GetPictureUrlError'
 
